Trident Chemwidgets - Docs v0.1

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Trident Chemwidgets

The Trident Chemwidgets package contains Jupyter-based interactive widgets that provide an interface to chemical datasets. This package includes widgets for chemical input, data distribution analysis and splitting, and atom-level visualizations. The video below gives an overview of the included functionality.

Your browser does not support the video tag.

## Quickstart

To get started with trident_chemwidgets, install with pip:

    pip install trident-chemwidgets

or with conda:

    conda install -c conda-forge trident-chemwidgets

Then, if using Jupyter Lab, you may need to run:

    jupyter labextension install trident-chemwidgets

If the widgets still are not usable after simple installation, check out Installation.

## Contents

Getting started

- Introduction
  - Inputs
  - Data visualization
  - Outputs
- Installation
  - JupyterLab activation
  - Notebook activation
  - Installation issues

Usage

- Widgets
  - Histogram
  - InteractiveMolecule
  - JSME
  - Scatter
- Examples
  - Using the Histogram widget
  - Using the InteractiveMolecule widget
  - Using the JSME widget
  - Using the Scatter widget

Development

- Developer install

API

- trident-chemwidgets
  - setup module
  - trident_chemwidgets package